==> generic-sequence-panel-1.1.0.tgz: package/esm/components/GenericGeneSeqPanel.js <==
// eslint-disable-next-line @typescript-eslint/no-unused-vars
import React, { useState, useEffect } from "react";
import GenericSeqPanel from "./GenericSeqPanel";
import transcriptList from "../fetchTranscripts";
export default function GenericGeneSeqPanel(props) {
    const { nclistbaseurl, fastaurl, refseq, start, end, gene, urltemplate } = props;
    const [result, setResult] = useState();
    const [error, setError] = useState();
    const [transcript, setTranscript] = useState();
    const [mode, setMode] = useState("gene");
    const feature = transcript || (result === null || result === void 0 ? void 0 : result[0]);
    useEffect(() => {
        (async () => {
            try {
                const res = await transcriptList({
                    nclistbaseurl,
                    fastaurl,
                    refseq,
                    start,
                    end,
                    gene,
                    urltemplate,
                });
                setResult(res);
            }
            catch (e) {
                console.error(e);
                setError(e);
            }
        })();
    }, [nclistbaseurl, fastaurl, refseq, start, end, gene, urltemplate]);
    if (error) {
        return React.createElement("div", { style: { color: "red" } }, `${error}`);
    }
    else if (!result) {
        return React.createElement("div", null, "Loading...");
    }
    else {
        return (React.createElement("div", { className: "GenericGeneSeqPanel" },
            "Transcript:",
            React.createElement("select", { onChange: e => setTranscript(result.find(r => r.id() === e.target.value)) }, result.map(r => (React.createElement("option", { key: r.id(), value: r.id() }, r.get("name"))))),
            "Mode:",
            React.createElement("select", { onChange: e => setMode(e.target.value) },
                React.createElement("option", { value: "gene" }, "gene"),
                React.createElement("option", { value: "cds" }, "CDS"),
                React.createElement("option", { value: "cdna" }, "cDNA"),
                React.createElement("option", { value: "protein" }, "protein"),
                React.createElement("option", { value: "genomic" }, "genomic"),
                React.createElement("option", { value: "genomic_sequence_updown" }, "genomic +500bp up and down stream"),
                React.createElement("option", { value: "gene_collapsed_intron" }, "gene with colapsed introns"),
                React.createElement("option", { value: "gene_updownstream" }, "gene with 500bp up and down stream"),
                React.createElement("option", { value: "gene_updownstream_collapsed_intron" }, "gene with 500bp up and down stream and colapsed introns")),
            React.createElement("br", null),
            feature ? (React.createElement(GenericSeqPanel, { ...props, transcript: feature, mode: mode })) : null));
    }
}

==> generic-sequence-panel-1.1.1.tgz: package/esm/components/GenericGeneSeqPanel.js <==
// eslint-disable-next-line @typescript-eslint/no-unused-vars
import React, { useState, useEffect } from "react";
import GenericSeqPanel from "./GenericSeqPanel";
import transcriptList from "../fetchTranscripts";
export default function GenericGeneSeqPanel(props) {
    const { nclistbaseurl, fastaurl, refseq, start, end, gene, urltemplate } = props;
    const [result, setResult] = useState();
    const [error, setError] = useState();
    const [transcript, setTranscript] = useState();
    const [mode, setMode] = useState("gene");
    const feature = transcript || (result === null || result === void 0 ? void 0 : result[0]);
    useEffect(() => {
        (async () => {
            try {
                const res = await transcriptList({
                    nclistbaseurl,
                    fastaurl,
                    refseq,
                    start,
                    end,
                    gene,
                    urltemplate,
                });
                setResult(res);
            }
            catch (e) {
                console.error(e);
                setError(e);
            }
        })();
    }, [nclistbaseurl, fastaurl, refseq, start, end, gene, urltemplate]);
    if (error) {
        return React.createElement("div", { style: { color: "red" } }, `${error}`);
    }
    else if (!result) {
        return React.createElement("div", null, "Loading...");
    }
    else {
        return (React.createElement("div", { className: "GenericGeneSeqPanel" },
            "Transcript:",
            React.createElement("select", { onChange: e => setTranscript(result.find(r => r.id() === e.target.value)) }, result.map(r => (React.createElement("option", { key: r.id(), value: r.id() }, r.get("name"))))),
            "Mode:",
            React.createElement("select", { onChange: e => setMode(e.target.value) },
                React.createElement("option", { value: "gene" }, "gene"),
                React.createElement("option", { value: "cds" }, "CDS"),
                React.createElement("option", { value: "cdna" }, "cDNA"),
                React.createElement("option", { value: "protein" }, "protein"),
                React.createElement("option", { value: "genomic" }, "genomic"),
                React.createElement("option", { value: "genomic_sequence_updown" }, "genomic +500bp up and down stream"),
                React.createElement("option", { value: "gene_collapsed_intron" }, "gene with collapsed introns"),
                React.createElement("option", { value: "gene_updownstream" }, "gene with 500bp up and down stream"),
                React.createElement("option", { value: "gene_updownstream_collapsed_intron" }, "gene with 500bp up and down stream and collapsed introns")),
            React.createElement("br", null),
            feature ? (React.createElement(GenericSeqPanel, { ...props, transcript: feature, mode: mode })) : null));
    }
}
